Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@gmail.com>2018-07-06 20:59:17 +0300
committerBrecht Van Lommel <brechtvanlommel@gmail.com>2018-07-06 20:59:17 +0300
commit6aa8e130eff59059886e203ff95221609f63b222 (patch)
treefe478c4920c5b2f602349eb2c216d2b653b5176b /io_export_unreal_psk_psa.py
parent7216192171a35c56523f9abcb279eb8a0a33577b (diff)
Update for renaming lamp to light.
Diffstat (limited to 'io_export_unreal_psk_psa.py')
-rw-r--r--io_export_unreal_psk_psa.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/io_export_unreal_psk_psa.py b/io_export_unreal_psk_psa.py
index ca22ca46..ca331912 100644
--- a/io_export_unreal_psk_psa.py
+++ b/io_export_unreal_psk_psa.py
@@ -1201,8 +1201,8 @@ def parse_mesh(mesh, psk):
# does with the mesh Y coordinates. this is otherwise known as MAGIC-2
uv[1] = 1.0 - uv[1]
- # clamp UV coords if udk_option_clamp_uv is True
- if bpy.context.scene.udk_option_clamp_uv:
+ # clamp UV coords if udk_option_clight_uv is True
+ if bpy.context.scene.udk_option_clight_uv:
if (uv[0] > 1):
uv[0] = 1
if (uv[0] < 0):
@@ -2422,7 +2422,7 @@ class Panel_UDKExport(Panel):
object_name = context.active_object.name
row10 = layout.row()
row10.prop(context.scene, "udk_option_smoothing_groups")
- row10.prop(context.scene, "udk_option_clamp_uv")
+ row10.prop(context.scene, "udk_option_clight_uv")
row10.prop(context.scene, "udk_option_verbose")
row = layout.row()
@@ -2792,7 +2792,7 @@ class ExportUDKAnimData(Operator):
scene = context.scene
layout.prop(scene, "udk_option_smoothing_groups")
- layout.prop(scene, "udk_option_clamp_uv")
+ layout.prop(scene, "udk_option_clight_uv")
layout.prop(scene, "udk_option_verbose")
layout.prop(scene, "udk_option_filename_src")
layout.prop(scene, "udk_option_export")
@@ -2888,7 +2888,7 @@ def register():
description="Boolean for exporting psa format (Animation Data)",
default=True
)
- bpy.types.Scene.udk_option_clamp_uv = BoolProperty(
+ bpy.types.Scene.udk_option_clight_uv = BoolProperty(
name="Clamp UV",
description="True is to limit Clamp UV co-ordinates to [0-1]. False is unrestricted (x,y)",
default=False
@@ -2977,7 +2977,7 @@ def unregister():
del bpy.types.Scene.udk_option_filename_src
del bpy.types.Scene.udk_option_export_psk
del bpy.types.Scene.udk_option_export_psa
- del bpy.types.Scene.udk_option_clamp_uv
+ del bpy.types.Scene.udk_option_clight_uv
del bpy.types.Scene.udk_copy_merge
del bpy.types.Scene.udk_option_export
del bpy.types.Scene.udk_option_verbose